pub struct AsyncLockFile { /* private fields */ }Expand description
An async LockFile.
Implemented by blocking on the tokio threadpool
Implementations
Sourceimpl AsyncLockFile
impl AsyncLockFile
Sourcepub fn blocking_open<P>(path: &P) -> Result<Self>where
P: ToOsStr + ?Sized,
pub fn blocking_open<P>(path: &P) -> Result<Self>where
P: ToOsStr + ?Sized,
Open a file for locking in a blocking manner
Sourcepub async fn lock_with_pid(&self) -> Result<()>
pub async fn lock_with_pid(&self) -> Result<()>
Lock the file, writing the PID to it
Sourcepub async fn try_lock(&self) -> Result<bool>
pub async fn try_lock(&self) -> Result<bool>
Try to lock the file, returning true if successful.
Sourcepub async fn try_lock_with_pid(&self) -> Result<bool>
pub async fn try_lock_with_pid(&self) -> Result<bool>
Try to lock a file with a pid, returning true if successful.
Sourcepub fn try_lock_with_pid_blocking(&self) -> Result<bool>
pub fn try_lock_with_pid_blocking(&self) -> Result<bool>
Try to lock a file with a pid, returning true if successful in a blocking manner.
Sourcepub fn blocking_unlock(&self) -> Result<()>
pub fn blocking_unlock(&self) -> Result<()>
Unlock the file in a blocking manner